<!--
SPDX-FileCopyrightText: AISEC Pentesting Team

SPDX-License-Identifier: CC0-1.0
-->

# Public API

## gallia.command

```{eval-rst}
.. automodule:: gallia.command
    :members:
    :show-inheritance:
```

## gallia.log

```{eval-rst}
.. automodule:: gallia.log
    :members:
    :show-inheritance:
```

## gallia.plugins

```{eval-rst}
.. automodule:: gallia.plugins
    :members:
    :show-inheritance:
```

## gallia.services.uds

```{eval-rst}
.. automodule:: gallia.services.uds
    :members:
    :show-inheritance:
```

## gallia.transports

All available transports are documented in {doc}`../transports`.

```{eval-rst}
.. automodule:: gallia.transports
    :members:
    :show-inheritance:
```
